# Vision UI

![GitHub](https://img.shields.io/badge/Python-3.6-blue)
![GitHub](https://img.shields.io/github/license/Meituan-Dianping/vision-diff)

> 移动端UI处理算法

## 目录

* [图像对比算法](resources/vision_diff_en.md)

* [图像文本识别](resources/vision_text.md)

* [活动弹窗识别](https://github.com/Meituan-Dianping/vision)


## 快速开始

* [启动服务](resources/container_service.md)


<img width="600" src="./image/image_6.png"/>

<img width="600" src="./image/vision_text_1.png"/>


## License

This project is licensed under the [MIT](./LICENSE) 


